function obj = compute_obj_function(X, y, s, Omega, params)
    
    % Input:
        % X: Datapoints (as columns)
        % y: labels
        % s: signs of w
        % Omega: where to compute g
        % params (all required):
            % .alpha: alpha; .beta: beta, .nu1: nu1, .nu2: nu2
            
    % Output: the function g at Omega

    %  Alhussein Fawzi.
    %  Signal Processing Laboratory (LTS4)
    %  EPFL, Lausanne, Switzerland.
    %  alhussein.fawzi@epfl.ch
    %
    %  February 2014
    
    alpha = params.alpha; beta = params.beta; nu = params.nu;
    n = size(X, 1);
    m = size(X, 2);
    
    X_prime = [X; -alpha * ones(1, m)];
    Z = 1/beta * log_one_exp(beta*(Omega'*X_prime));
    
    arg1 = zeros(1, m);
    arg2 = zeros(1, m);
    
    arg1(y == 1) = sum(Z(s == 1, y == 1), 1); arg1(y == -1) = sum(Z(s == -1, y == -1), 1);
    arg2(y == 1) = 1 + sum(Z(s == -1, y == 1), 1); arg2(y == -1) = 1 + sum(Z(s == 1, y == -1), 1);
    obj = sum(max(0, arg2 - arg1)) + nu/2 * norm(Omega(n+1, :), 2)^2;
end