function [obj, g, h_linearized] = compute_obj_function_linearized(X, y, s, Omega, Omega_old, Omega_grad, params)
    % Input:
        % X: Datapoints (as columns)
        % y: labels
        % s: signs of w
        % Omega: where to COMPUTE this function
        % Omega_old: where the linearization has taken place
        % Omega_grad: gradient of h around Omega_old
        % params (all required):
            % .alpha: alpha; .beta: beta, .nu1: nu1, .nu2: nu2
            
    % Output: {g - (Linearization of h around Omega_old)} evaluated at Omega.

    %  Alhussein Fawzi.
    %  Signal Processing Laboratory (LTS4)
    %  EPFL, Lausanne, Switzerland.
    %  alhussein.fawzi@epfl.ch
    %
    %  February 2014
    
    alpha = params.alpha; beta = params.beta; nu = params.nu;
    n = size(X, 1);
    m = size(X, 2);
    X_prime = [X; -alpha * ones(1, m)];
    Z = 1/beta * log_one_exp(beta*(Omega'*X_prime));
    
    arg1 = zeros(1, m);
    arg2 = zeros(1, m);    
    
    arg1(y == 1) = sum(Z(s == 1, y == 1), 1); arg1(y == -1) = sum(Z(s == -1, y == -1), 1);
    arg2(y == 1) = 1 + sum(Z(s == -1, y == 1), 1); arg2(y == -1) = 1 + sum(Z(s == 1, y == -1), 1);
    g = sum(max(arg1, arg2)) + nu/2 * norm(Omega(n+1, :), 2)^2;

    Z_old = 1/beta * log_one_exp(beta*(Omega_old'*X_prime));
    
    arg1 = zeros(1, m);
    arg1(y == 1) = sum(Z_old(s == 1, y == 1), 1); arg1(y == -1) = sum(Z_old(s == -1, y == -1), 1);
    h_linearized = sum( arg1 ) + trace(Omega_grad' * (Omega - Omega_old) );
    
    obj = g - h_linearized;
end