function Omega_grad = gradient_g(X, y, s, Omega, params)
    % Input:
        % X: Datapoints (as columns)
        % y: labels
        % s: signs of w
        % Omega: where to compute the gradient
        % params (all required):
            % .alpha: alpha; .beta: beta
            
    % Output: the gradient of of g at Omega
    
    %  Alhussein Fawzi.
    %  Signal Processing Laboratory (LTS4)
    %  EPFL, Lausanne, Switzerland.
    %  alhussein.fawzi@epfl.ch
    %
    %  February 2014
    
    n = size(X, 1);
    m = size(X, 2);
    
    alpha = params.alpha; beta = params.beta;
    
    % Compute Z and Z_grad
    X_prime = [X; -alpha * ones(1, m)];
    
    temp = beta*(Omega'*X_prime);
    
    [Z,Z_grad] = sigmoid_log_one_exp(temp);
    Z = 1/beta * Z;
    
    % Compute the gradient of Omega
    arg1 = zeros(1, m);
    arg2 = zeros(1, m);
    
    Omega_grad = zeros(size(Omega));
    s = s(:)';
    
    arg1(y == 1) = sum(Z(s == 1, y == 1), 1); arg1(y == -1) = sum(Z(s == -1, y == -1), 1);
    arg2(y == 1) = 1 + sum(Z(s == -1, y == 1), 1); arg2(y == -1) = 1 + sum(Z(s == 1, y == -1), 1);
    
    i1 = find(arg1 >= arg2);
    i2 = find(arg1 < arg2);
    y_plus = find(y == 1);
    y_moins = find(y == -1);
    
    i1_plus = i1(ismembc(i1, y_plus)); i1_moins = i1(ismembc(i1, y_moins));
    i2_plus = i2(ismembc(i2, y_plus)); i2_moins = i2(ismembc(i2, y_moins));
    
    Omega_grad(:, s == 1) = X_prime(:, i1_plus) * Z_grad(s == 1, i1_plus)' + X_prime(:, i2_moins) * Z_grad(s == 1, i2_moins)';
    Omega_grad(:, s == -1) = X_prime(:, i1_moins) * Z_grad(s == -1, i1_moins)' + X_prime(:, i2_plus) * Z_grad(s == -1, i2_plus)';
    
end