function Omega_grad = gradient_h(X, y, s, Omega, params)
    % Input:
        % X: Datapoints (as columns)
        % y: labels
        % s: signs of w
        % Omega: where to compute the gradient
        % params (all required):
            % .alpha: alpha; .beta: beta
            
    % Output: the gradient of of h at Omega
    
    %  Alhussein Fawzi.
    %  Signal Processing Laboratory (LTS4)
    %  EPFL, Lausanne, Switzerland.
    %  alhussein.fawzi@epfl.ch
    %
    %  February 2014
    
    alpha = params.alpha; beta = params.beta;
    m = size(X, 2); 
    
    X_prime = [X; -alpha * ones(1, m)];
    Z = sigmoid_fun(beta*(Omega' * X_prime));
    
    Omega_grad = zeros(size(Omega));
    Omega_grad(:, s == 1) = X_prime(:, y == 1) * Z(s == 1, y == 1)';
    Omega_grad(:, s == -1) = X_prime(:, y == -1) * Z(s == -1, y == -1)';
end